# Makes FIGURE 3 in Hurford et al. Graphs the stage structure and salmon lice dynamics.
library(PBSddesolve)
library(chron)
# Set the path to your directory
setwd("/Users/amyhurford/Desktop/Code")
load("ParamsFuncs.RData")
# Function that performs the numerical integration
sealice=function(t0,tfin,A0,C0,I0,P0,mu,g,b1,b2,d1,d2){
  # The seasonality in temperature and salinity
  Temp = function(t){
    Temp = a + b1*sin(2 * pi * t/365) + b2*cos(2 * pi * t/365)
    return(Temp)
  }
  S = function(t){
    S = c + d1*sin(2 * pi * t/365) + d2*cos(2 * pi * t/365)
    return(S)
  } 
  
  ## Function to calculate the gradient
  lice = function(t, y){
    tp0 = tpINIT()
    tc0 = tcINIT()
    PhiP0 = exp(-(integrate(mortalityP, t0 - tp0, t0)$value))
    PhiC0 = exp(-(integrate(mortalityC, t0 - tc0, t0)$value))
    # List of all initial Values
    yinit <- c(A0, P0, tp0, I0, C0, tc0,PhiP0, PhiC0);
    # The number of adult females
    A = y[1]
    # The number of plaktonic larvae
    P = y[2]
    # The time delay for the planktonic stage
    tp = y[3]
    # The number of infectious copepodids
    I = y[4]
    # The number of chalimus
    C = y[5]
    # The time delay for the chalimus stage
    tc = y[6]
    # Mortality durign the planktonic stage
    PhiP = y[7]
    # Mortality during the chalimus stage
    PhiC = y[8]
    
    # Apply timelags only once enough history has been established:
    if (t - tp < t0) {
      # The value of the lagged variables. Setting them equal to 0 means no lag.
      lagp = yinit
    } else{
      # if the logical test passses we can calculate the lags
      lagp = pastvalue(t - tp)
    }
    
    if (t - tc < t0) {
      # The value of the lagged variables. Setting them equal to 0 means no lag.
      lagc = yinit
    } else{
      # if the logical test passses we can calculate the lags
      lagc = pastvalue(t - tc)
    }
    
    # The system of DDEs
    P1 =  eta(Temp(t))*epsilon(Temp(t))*A*V(Temp(t),S(t))-eta(Temp(t-tp))*epsilon(Temp(t-tp))*lagp[1]*(gammaP(Temp(t))/gammaP(Temp(t-tp)))*V(Temp(t-tp),S(t-tp))*PhiP-mup(S(t))*P
    I1 =  (1/mu)*eta(Temp(t-tp))*epsilon(Temp(t-tp))*lagp[1]*(gammaP(Temp(t))/gammaP(Temp(t-tp)))*V(Temp(t-tp),S(t-tp))*PhiP-iota*g*f*I-mui(S(t))*I
    C1 = iota*g*f*I-iota*f*lagc[4]*(gammaC(Temp(t))/gammaC(Temp(t-tc)))*PhiC-muc(S(t))*C
    A1 = (1/mu)*((iota*g*f*lagc[4]*(gammaC(Temp(t))/gammaC(Temp(t-tc)))*PhiC)/2)-mua(S(t))*A
    
    tp1 = 1 - gammaP(Temp(t))/gammaP(Temp(t-tp))
    tc1 = 1 - gammaC(Temp(t))/gammaC(Temp(t-tc))
    
    PhiP1 = PhiP*(gammaP(Temp(t))*mup(S(t-tp))/gammaP(Temp(t-tp))-mup(S(t)))
    PhiC1 = PhiC*(gammaC(Temp(t))*muc(S(t-tc))/gammaC(Temp(t-tc))-muc(S(t)))
    return(c(A1, P1, tp1, I1, C1, tc1, PhiP1, PhiC1))
  }
  # List of all paremeter Values
  parameters = c(eta, epsilon, iota, V, mup, mui, muc, mua, t0, tfin, mup, f)   
  tp0 = tpINIT()
  tc0 = tcINIT()
  PhiP0 = exp(-(integrate(mortalityP, t0 - tp0, t0)$value))
  PhiC0 = exp(-(integrate(mortalityC, t0 - tc0, t0)$value))
  # List of all initial Values
  yinit <- c(A0, P0, tp0, I0, C0, tc0, PhiP0, PhiC0);
  x = dde(y = yinit, func = lice, parms = parameters, times = seq(t0, tfin, 1), hbsize = 1000000)
  return(x)
}

SummaryX=function(x){
  # Keep only data in the last year - approach steady state
  data2 = x[x$time>=365*2,]-2*365
  data3 = x[x$time>=365*2-1,]-2*365
  NperI = data2$y2/data2$y4
  PropC = data2$y5/(data2$y5+2*data2$y1)
  LarvMot = (data2$y2+ data2$y4)/(data2$y5+2*data2$y1)
  time = data2$time
  diffA = 2*diff(data3$y1)
  diffM = diffA+diff(data3$y5)
  diffN = diff(data3$y2)+diff(data3$y4)+diffM
  SummaryX = data.frame(PropC,LarvMot,time,diffA, diffN,diffM,NperI)
  return(SummaryX)
}

t1 = seq(1,365)
load('farm24.RData')
x24 = sealice(1,3*365,f,0,0,0,1,1,b1,b2,d1,d2)
SS24 = SummaryX(x24)

load('farmCC.RData')
xCC = sealice(1,3*365,f,0,0,0,1,1,b1,b2,d1,d2)
SSCC = SummaryX(xCC)

load('farmWCVI.RData')
xWCVI = sealice(1,3*365,f,0,0,0,1,1,b1,b2,d1,d2)
SSWCVI = SummaryX(xWCVI)

load('farmNB.RData')
xNB = sealice(1,3*365,f,0,0,0,1,1,b1,b2,d1,d2)
xNB$y2[xNB$y2<0]=0
SSNB = SummaryX(xNB)

load('farmNS.RData')
xNS = sealice(1,3*365,f,0,0,0,1,1,b1,b2,d1,d2)
xNS$y2[xNS$y2<0]=0
SSNS = SummaryX(xNS)

load('farmNL.RData')
# Mean salinity
c<-31
d1<-0
d2<-0
xNL = sealice(1,3*365,f,0,0,0,1,1,b1,b2,d1,d2)
SSNL = SummaryX(xNL)

load('farmCH.RData')
# salinity set to 31 - near the mean for the Canadian sites (excluding NL)
c<-31
xCH = sealice(1,3*365,f,0,0,0,1,1,b1,b2,d1,d2)
SSCH = SummaryX(xCH)

load('farmNIN.RData')
xNIN = sealice(1,3*365,f,0,0,0,1,1,b1,b2,d1,d2)
SSNIN = SummaryX(xNIN)

load('farmNLI.RData')
xNLI = sealice(1,3*365,f,0,0,0,1,1,b1,b2,d1,d2)
SSNLI = SummaryX(xNLI)

load('farmIM3.RData')
xIM3 = sealice(1,3*365,f,0,0,0,1,1,b1,b2,d1,d2)
SSIM3 = SummaryX(xIM3)

load('farmIM4.RData')
xIM4 = sealice(1,3*365,f,0,0,0,1,1,b1,b2,d1,d2)
SSIM4 = SummaryX(xIM4)

# Making the figures
par(mfrow = c(4,1),mar=c(2.5, 3, 1, 1), mgp=c(1.5, .5, 0))
plot(xNB$time/365,xNB$y1/f, xlab = "", ylab = "A(t)/f", typ="l", lwd=2, col = "darkred", xaxt="n", bty="l")
lines(x24$time/365,x24$y1/f, lwd=2, col="blue")
lines(xWCVI$time/365,xWCVI$y1/f, lwd=2, col="dodgerblue")
lines(xCC$time/365, xCC$y1/f, lwd=2, col="deepskyblue")
lines(xNS$time/365, xNS$y1/f, lwd=2, col="darkorange")
lines(xNL$time/365, xNL$y1/f, lwd=2, col="darkgoldenrod1")
lines(xCH$time/365, xCH$y1/f, lwd=2, col = "deepskyblue")
lines(xNIN$time/365, xNIN$y1/f, lwd=2, col = "blue4")
lines(xNLI$time/365, xNLI$y1/f, lwd=2, col = "red3")
lines(xIM3$time/365, xIM3$y1/f, lwd=2, col = "darkorange")
lines(xIM4$time/365, xIM4$y1/f, lwd=2, col="forestgreen")
axis(1,at=c(1,32,60,91,121,152,182,213,244,274,305,335,366, 397,425,456,486,517,547,578,609,639,670,700,731),labels=c("Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec", "Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec", "Jan"), las=2)

#Order as CH, IM3, IM4, 24, WCVI, CC, NIN, NLI, NB, NS, NL
plot(c(-110,-110), c(min(SSCH$PropC), max(SSCH$PropC)), col = "deepskyblue", lwd=10, xlim = c(-100,365),ylim=c(0,1), ylab = "Prop. motiles that are C", xaxt="n", xlab = "",typ="l", bty = "l")
lines(c(-100,-100), c(min(SSIM3$PropC), max(SSIM3$PropC)), col = "darkorange", lwd=10)
lines(c(-90,-90), c(min(SSIM4$PropC), max(SSIM4$PropC)), col = "forestgreen", lwd=10)
lines(c(-80,-80), c(min(SS24$PropC), max(SS24$PropC)),lwd=10, col = "blue4")
lines(c(-70,-70), c(min(SSWCVI$PropC),max(SSWCVI$PropC)), col="dodgerblue", lwd=10)
lines(c(-60,-60), c(min(SSCC$PropC),max(SSCC$PropC)), col = "deepskyblue", lwd=10)
lines(c(-50,-50), c(min(SSNIN$PropC), max(SSNIN$PropC)), col = "blue4", lwd=10)
lines(c(-40,-40), c(min(SSNLI$PropC), max(SSNLI$PropC)), col = "red3", lwd=10)
lines(c(-30,-30), c(min(SSNB$PropC), max(SSNB$PropC)), col = "darkred", lwd=10)
lines(c(-20,-20), c(min(SSNS$PropC), max(SSNS$PropC)), col = "darkorange", lwd=10)
lines(c(-10,-10), c(min(SSNL$PropC), max(SSNL$PropC)), col = "darkgoldenrod1", lwd=10)

lines(SS24$time, SS24$PropC, col="blue", lwd=2)
lines(SSWCVI$time, SSWCVI$PropC, col = "dodgerblue", lwd=2)
lines(SSCC$time, SSCC$PropC, col="deepskyblue", lwd=2)
lines(SSNB$time, SSNB$PropC, col = "darkred", lwd=2)
lines(SSNS$time, SSNS$PropC, col = "darkorange", lwd=2)
lines(SSNL$time, SSNL$PropC, col="darkgoldenrod1", lwd=2)
lines(SSCH$time, SSCH$PropC, col = "deepskyblue", lwd=2)
lines(SSNIN$time, SSNIN$PropC, col="blue4", lwd=2)
lines(SSNLI$time, SSNLI$PropC, col = "red3", lwd=2)
lines(SSIM3$time, SSIM3$PropC, col = "darkorange", lwd=2)
lines(SSIM4$time, SSIM4$PropC, col = "forestgreen", lwd=2)
axis(1,at=c(-110, -100,-90, -80, -70,-60,-50,-40,-30,-20,-10,1,32,60,91,121,152,182,213,244,274,305,335,366),labels=c("CH", "IM3", "IM4", "BCB", "BCW", "BCC", "NIN", "NLI", "NB", "NS", "(NL)","Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec", "Jan"),las=2)

plot(c(-110,-110), c(min(SSCH$LarvMot), max(SSCH$LarvMot)), col = "deepskyblue", lwd=10, xlim = c(-100,365),ylim=c(0,140), ylab = "Larvae/Motile", xaxt="n", xlab = "",typ="l", bty = "l")
lines(c(-100,-100), c(min(SSIM3$LarvMot), max(SSIM3$LarvMot)), col = "darkorange", lwd=10)
lines(c(-90,-90), c(min(SSIM4$LarvMot), max(SSIM4$LarvMot)), col = "forestgreen", lwd=10)
lines(c(-80,-80), c(min(SS24$LarvMot), max(SS24$LarvMot)),lwd=10, col = "blue")
lines(c(-70,-70), c(min(SSWCVI$LarvMot),max(SSWCVI$LarvMot)), col="dodgerblue", lwd=10)
lines(c(-60,-60), c(min(SSCC$LarvMot),max(SSCC$LarvMot)), col = "deepskyblue", lwd=10)
lines(c(-50,-50), c(min(SSNIN$LarvMot), max(SSNIN$LarvMot)), col = "blue4", lwd=10)
lines(c(-40,-40), c(min(SSNLI$LarvMot), max(SSNLI$LarvMot)), col = "red3", lwd=10)
lines(c(-30,-30), c(min(SSNB$LarvMot), max(SSNB$LarvMot)), col = "darkred", lwd=10)
lines(c(-20,-20), c(min(SSNS$LarvMot), max(SSNS$LarvMot)), col = "darkorange", lwd=10)
lines(c(-10,-10), c(min(SSNL$LarvMot), max(SSNL$LarvMot)), col = "darkgoldenrod1", lwd=10)
lines(SS24$time, SS24$LarvMot, col="blue", lwd=2)
lines(SSWCVI$time, SSWCVI$LarvMot, col = "dodgerblue", lwd=2)
lines(SSCC$time, SSCC$LarvMot, col="deepskyblue", lwd=2)
lines(SSNB$time, SSNB$LarvMot, col = "darkred", lwd=2)
lines(SSNS$time, SSNS$LarvMot, col = "darkorange", lwd=2)
lines(SSNL$time, SSNL$LarvMot, col="darkgoldenrod1", lwd=2, lty=1)
lines(SSCH$time, SSCH$LarvMot, col = "deepskyblue", lwd=2)
lines(SSNIN$time, SSNIN$LarvMot, col="blue4", lwd=2)
lines(SSNLI$time, SSNLI$LarvMot, col = "red3", lwd=2)
lines(SSIM3$time, SSIM3$LarvMot, col = "darkorange", lwd=2)
lines(SSIM3$time, SSIM3$LarvMot, col = "forestgreen", lwd=2)
axis(1,at=c(-110, -100,-90, -80, -70,-60,-50,-40,-30,-20,-10,1,32,60,91,121,152,182,213,244,274,305,335,366),labels=c("CH", "IM3", "IM4", "BCB", "BCW", "BCC", "NIN", "NLI", "NB", "NS", "(NL)","Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec", "Jan"),las=2)

plot(c(-110,-110), c(0, length(SSCH[SSCH$diffM>0,1])/365), col = "deepskyblue", lwd=10, xlim = c(-100,365),ylim=c(0,1.1), ylab = "Prop. yr motiles incr.", xaxt="n", xlab = "",typ="l", bty = "l")
lines(c(-100,-100), c(0,length(SSIM3[SSIM3$diffM>0,1])/365), col = "darkorange", lwd=10)
lines(c(-90,-90), c(0, length(SSIM4[SSIM4$diffM>0,1])/365), col = "forestgreen", lwd=10)
lines(c(-80,-80), c(0, length(SS24[SS24$diffM>0,1])/365),lwd=10, col = "blue")
lines(c(-70,-70), c(0,length(SSWCVI[SSWCVI$diffM>0,1])/365), col="dodgerblue", lwd=10)
lines(c(-60,-60), c(0,length(SSCC[SSCC$diffM>0,1])/365), col = "deepskyblue", lwd=10)
lines(c(-50,-50), c(0, length(SSNIN[SSNIN$diffM>0,1])/365), col = "blue4", lwd=10)
lines(c(-40,-40), c(0, length(SSNLI[SSNLI$diffM>0,1])/365), col = "red3", lwd=10)
lines(c(-30,-30), c(0, length(SSNB[SSNB$diffM>0,1])/365), col = "darkred", lwd=10)
lines(c(-20,-20), c(0, length(SSNS[SSNS$diffM>0,1])/365), col = "darkorange", lwd=10)
lines(c(-10,-10), c(0, length(SSNL[SSNL$diffM>0,1])/365), col = "darkgoldenrod1", lwd=10)
points(SS24$time, sign(SS24$diffM)-.7, col = "blue")
text(375,.3, "BCB", col="blue")
points(SSWCVI$time, sign(SSWCVI$diffM)-.6, col = "dodgerblue", lwd=1, pch=16)
text(375, 0.4, "BCV", col = "dodgerblue")
points(SSCC$time, sign(SSCC$diffM)-.5, col = "deepskyblue", lwd=1,pch=16)
text(375, 0.5,"BCC", col = "deepskyblue")
points(SSNB$time, sign(SSNB$diffM)-.2, col = "darkred", lwd=1,pch=16)
text(372, 0.8, "NB", col = "darkred")
points(SSNS$time, sign(SSNS$diffM)-.1, col = "darkorange", lwd=1, pch=16)
text(372, 0.9, "NS", col = "darkorange")
points(SSWCVI$time, sign(SSNL$diffM), col = "darkgoldenrod1", lwd=1, pch=16)
text(372,1,"(NL)", col = "darkgoldenrod1")
points(SSCH$time, sign(SSCH$diffM)-1, col = "deepskyblue", lwd=1, pch=16)
text(375, 0, "CH", col = "deepskyblue")
points(SSNB$time, sign(SSNIN$diffM)-.4, col = "blue4", lwd=1, pch=16)
text(374, .6, "NIN", col = "blue4")
points(SSNS$time, sign(SSNLI$diffM)-.3, col = "red3", lwd=1,pch=16)
text(373, .7, "NLI", col = "red3")
points(SSNB$time, sign(SSIM3$diffM)-.9, col = "darkorange", lwd=1, pch=16)
text(375, .1, "IM3", col = "darkorange")
points(SSNS$time, sign(SSIM4$diffM)-.8, col = "forestgreen", lwd=1,pch=16)
text(375, .2, "IM4", col = "forestgreen")
axis(1,at=c(-110, -100,-90, -80, -70,-60,-50,-40,-30,-20,-10,1,32,60,91,121,152,182,213,244,274,305,335,366),labels=c("CH", "IM3", "IM4", "BCB", "BCW", "BCC", "NIN", "NLI", "NB", "NS", "(NL)","Jan", "Feb", "Mar", "Apr", "May", "June", "July", "Aug", "Sept", "Oct", "Nov", "Dec", "Jan"),las=2)

# Stage structure on March 1.
SSNS[julian(3,1,1970)+1,]
SSNB[julian(3,1,1970)+1,]
SSNL[julian(3,1,1970)+1,]

SSNS[julian(9,1,1970)+1,]
SSNB[julian(9,1,1970)+1,]
SSNL[julian(9,1,1970)+1,]

# Prop. of year when motiles increasing
length(SSWCVI[SSWCVI$diffM>0,1])/365
length(SSCC[SSCC$diffM>0,1])/365
length(SSNIN[SSNIN$diffM>0,1])/365
length(SSNLI[SSNLI$diffM>0,1])/365
length(SSNIN[SSNIN$diffM>0,1])/365
length(SSNB[SSNB$diffM>0,1])/365
length(SSNS[SSNS$diffM>0,1])/365
length(SSNL[SSNL$diffM>0,1])/365